[maemo-commits] [maemo-commits] r12807 - in projects/haf/trunk/hail: . hail/hail-hildon-desktop

From: subversion at stage.maemo.org subversion at stage.maemo.org
Date: Tue Jul 24 15:10:40 EEST 2007
Author: fherrera
Date: 2007-07-24 15:10:38 +0300 (Tue, 24 Jul 2007)
New Revision: 12807

Modified:
   projects/haf/trunk/hail/ChangeLog
   projects/haf/trunk/hail/hail/hail-hildon-desktop/hailtogglebutton.c
Log:
2007-07-24  Fernando Herrera  <fernando.herrera-de-las-heras at nokia.com>

        * hail-hildon-desktop/hailtogglebutton.c: use new libhildonwm API.




Modified: projects/haf/trunk/hail/ChangeLog
===================================================================
--- projects/haf/trunk/hail/ChangeLog	2007-07-24 11:25:00 UTC (rev 12806)
+++ projects/haf/trunk/hail/ChangeLog	2007-07-24 12:10:38 UTC (rev 12807)
@@ -1,3 +1,7 @@
+2007-07-24  Fernando Herrera  <fernando.herrera-de-las-heras at nokia.com>
+
+	* hail-hildon-desktop/hailtogglebutton.c: use new libhildonwm API.
+
 2007-07-23  Fernando Herrera  <fernando.herrera-de-las-heras at nokia.com>
 
 	* configure.in: Release 1.2.2

Modified: projects/haf/trunk/hail/hail/hail-hildon-desktop/hailtogglebutton.c
===================================================================
--- projects/haf/trunk/hail/hail/hail-hildon-desktop/hailtogglebutton.c	2007-07-24 11:25:00 UTC (rev 12806)
+++ projects/haf/trunk/hail/hail/hail-hildon-desktop/hailtogglebutton.c	2007-07-24 12:10:38 UTC (rev 12807)
@@ -25,16 +25,16 @@
  * #HailToggleButton implements the required ATK interfaces of #AtkObject.
  * In particular it exposes (for HNAppButton):
  * <itemizedlist>
  * <listitem>The embedded control. It gets the name from the #HDEntryInfo taken the name
  it represents,
  * taken it from the #HDEntryInfo. When no applications are running, a
  * default name is given.</listitem>
  * <listitem>Added behaviour to action of clicking the toggle button</listitem>
  * </itemizedlist>
  */
 
 #include <gtk/gtktogglebutton.h>
-#include <libhildonwm/hd-entry-info.h>
+#include <libhildonwm/hd-wm-entry-info.h>
 #include <libhildonwm/hd-wm.h>
 #include "hailtogglebutton.h"
 
@@ -312,7 +312,7 @@
 	  /* top the selected app:
 	   * see hn-app-button:hn_app_button_pop_menu for details
 	   */
-          HDEntryInfo *info = NULL;
+          HDWMEntryInfo *info = NULL;
 
           /* entry-info is a pointer property,
            * so we mustn't free it with hd_entry_info_free
@@ -351,7 +351,7 @@
   /* accessibility HNAppButton initialize */
   if (g_type_is_a (G_TYPE_FROM_INSTANCE(toggle_button), hn_app_button_type))
     {
-      HDEntryInfo *info = NULL;
+      HDWMEntryInfo *info = NULL;
 
       /* entry-info is a pointer property,
        * so we mustn't free it with hd_entry_info_free
@@ -363,7 +363,7 @@
       if (info != NULL)
         {
           /* name of the application */
-          priv->name = hd_entry_info_peek_app_name (info);
+          priv->name = hd_wm_entry_info_peek_app_name (info);
         }
       else
         {
@@ -371,7 +371,7 @@
           priv->name = HAIL_HN_APP_BUTTON_DEFAULT_NAME;
         }
 
       /* connect for changes in the HDEntryInfo */
       g_signal_connect (G_OBJECT(toggle_button), "notify",
                         G_CALLBACK(hail_toggle_button_app_button_entry_changed_cb), obj); 
     }
@@ -390,10 +390,10 @@
   /* implementation for HNAppButton */
   if (g_type_is_a (G_TYPE_FROM_INSTANCE(toggle_button), hn_app_button_type))
     {
       /* check for HDEntryInfo property changes */
       if (g_ascii_strcasecmp (spec->name, "entry-info"))
         {
-          HDEntryInfo *info = NULL;
+          HDWMEntryInfo *info = NULL;
 
           /* entry-info is a pointer property,
            * so we mustn't free it with hd_entry_info_free
@@ -405,7 +405,7 @@
           if (info != NULL)
             {
               /* name of the application */
-              priv->name = hd_entry_info_peek_app_name (info);
+              priv->name = hd_wm_entry_info_peek_app_name (info);
             }
 	  else
 	    {
@@ -25,16 +25,16 @@
  * In particular it exposes (for HNAppButton):
  * <itemizedlist>
- * <listitem>The embedded control. It gets the name from the #HDEntryInfo taken the name
+ * <listitem>The embedded control. It gets the name from the #HDWMEntryInfo taken the name
  it represents,
@@ -25,16 +25,16 @@
  it represents,
- * taken it from the #HDEntryInfo. When no applications are running, a
+ * taken it from the #HDWMEntryInfo. When no applications are running, a
  * default name is given.</listitem>
  * <listitem>Added behaviour to action of clicking the toggle button</listitem>
@@ -371,7 +371,7 @@
         }
 
-      /* connect for changes in the HDEntryInfo */
+      /* connect for changes in the HDWMEntryInfo */
       g_signal_connect (G_OBJECT(toggle_button), "notify",
                         G_CALLBACK(hail_toggle_button_app_button_entry_changed_cb), obj); 
@@ -390,10 +390,10 @@
   if (g_type_is_a (G_TYPE_FROM_INSTANCE(toggle_button), hn_app_button_type))
     {
-      /* check for HDEntryInfo property changes */
+      /* check for HDWMEntryInfo property changes */
       if (g_ascii_strcasecmp (spec->name, "entry-info"))
         {


More information about the maemo-commits mailing list